@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2005 Oliver Heidelbach
+@c Copyright (C) 1993/2006 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -84,6 +84,9 @@ Computer Aided Design (CIM)
 @item CADE
 Computer Aided Document Engineering (Microstar)
 
+@item CADR
+Client Authenticated DNS Request (DNS, Internet)
+
 @item CADS
 Computer-Assisted Display System
 
@@ -141,6 +144,9 @@ Common Access Method (SCSI)
 @item CAM
 Computer Aided Manufacturing
 
+@item CAM
+Conditional Access Modul (DVB, CI)
+
 @item CAM
 Content Addressable Memory (ethernet, Switch)
 
@@ -153,6 +159,9 @@ Customized Applications for Mobile network Enhanced Logic (UMTS)
 @item CAMM
 Computer Assisted Material Management
 
+@item CAMP
+Cygwin Apache MySQL PHP (Cygwin, Apache, SQL, PHP)
+
 @item CAN
 Complete Area Networks (SNI)
 
@@ -204,6 +213,9 @@ CAnnon Printing System Language (Canon), "CaPSL"
 @item CAPTCHA
 Completely Automated Public Turing test to tell Humans from Computers Apart (AI)
 
+@item CAPWAP
+Control and Provisioning of Wireless Access Points (WAP)
+
 @item CAQ
 Computer Aided Quality [control]
 
@@ -222,6 +234,9 @@ Contents of the Address Register (IBM, ELISP, CDR)
 @item CARCAS
 Computer Aided aRchiving and Change Accounting System
 
+@item CARD
+Candidate Access Router Discovery (RFC 4066)
+
 @item CARDS
 Central Archive for Reusable Defense Software (mil., USA)
 
@@ -408,12 +423,18 @@ Country Code (MS-ISDN, GSM, mobile-systems)
 @item CC
 Cross Connector
 
+@item CCA
+Clear Channel Assessment (WLAN)
+
 @item CCAF
 Call Control Agent Function (IN)
 
 @item CCC
 Cablelabs Client Configuration (DHCP)
 
+@item CCC
+Catalyst Control Center (ATI, Windows)
+
 @item CCC
 Chaos Computer Club (org.)
 
@@ -486,6 +507,9 @@ CORBA Component Model (CORBA)
 @item CCM
 Counter with CBC-MAC (cryptography, CBC, MAC, RFC 3610)
 
+@item CCMDB
+Change and Configuration Management DataBase (IBM, Tivoli)
+
 @item CCMP
 Counter mode CBC MAC Protocol (CBC, MAC, cryptography, WLAN)
 
@@ -528,6 +552,9 @@ Center for Computer Research in Music and Acoustics (org., Stanford, UK)
 @item CCS
 Cambridge Cybernetic Society (org.)
 
+@item CCS
+Cluster Configuration System (GFS)
+
 @item CCS
 Coded Character Set (CCS, Unicode)
 
@@ -678,9 +705,15 @@ Compact Disk - Magneto Optical (CD), "CD-MO"
 @item CDMRW
 Compact Disk - Mount Rainier Washington (CD-RW, CD), "CD-MRW"
 
+@item CDMS
+Command and Data Management System (ESA, Venus-Express)
+
 @item CDMS
 Communication Driver Maintenance System (ISDN, HST)
 
+@item CDMU
+Command and Data Management Unit (ESA, Venus-Express, CDMS)
+
 @item CDNC
 Chinese DOMAIN Name Consortium (org., Internet, DOMAIN)
 
@@ -726,6 +759,9 @@ Compact Disk - ReWritable (CD), "CD-RW"
 @item CDS
 Cell Directory Service (DCE)
 
+@item CDS
+Class Data Sharing (Java)
+
 @item CDS
 Current Directory Structure (BIOS. DOS)
 
@@ -838,7 +874,7 @@ Comite Europeen de Normalisation (org., Europe, Brussels)
 Comite Europeen de Normalisation ELECtrotechnique (org., CEN, Europe)
 
 @item CENTR
-Council of European National Top level DOMAIN Registries
+Council of European National Top level DOMAIN Registries (org., TLD, DOMAIN)
 
 @item CEPAC
 CMOS-Ein-Platinen-Allzweck-Computer (IC, CMOS, C'T)
@@ -951,12 +987,18 @@ Center for Standards (org., JIEO, DISA)
 @item CFS
 Cryptographic FileSystem (Linux, cryptography)
 
+@item CFT
+Call For Testers
+
 @item CFV
 Call For Vote (Internet, Usenet), "CfV"
 
 @item CFWS
 Comments / Folding White Space (RFC 1822)
 
+@item CG
+C for Graphics (Nvidia, MS), "Cg"
+
 @item CGA
 Colour Graphics Adapter
 
@@ -984,6 +1026,9 @@ Computer Graphics Interface
 @item CGI
 Computer Graphics International (conference)
 
+@item CGL
+Carrier Grade Linux (Linux, OSDL)
+
 @item CGM
 Computer Graphics Metafile (ISO 8632)
 
@@ -1035,6 +1080,9 @@ Check In (RCS)
 @item CI
 Coded Information
 
+@item CI
+Common Interface (DVB)
+
 @item CI
 Component Interface (DMI)
 
@@ -1059,6 +1107,9 @@ Computer Integrated Business
 @item CIC
 Carrier Identification Code
 
+@item CIC
+Certified IT Consultant (BVSI)
+
 @item CIC
 Coordination and Information Center (CSNET)
 
@@ -1086,6 +1137,9 @@ Common Intrusion Detection Framework (CIDF, IDS)
 @item CIDR
 Classless Internet DOMAIN Routing [protocol] (RFC 1519)
 
+@item CIDS
+Cabin Intercommunication Data System (Airbus, A380, TCP/IP)
+
 @item CIE
 Commission Internationale de l'Eclairage (org.)
 
@@ -1152,6 +1206,9 @@ Customer Information Quality (OASIS, TC)
 @item CIR
 Committed Information Rate (ATM)
 
+@item CIRAS
+(Conference on] Computational Intelligence, Robotics and Autonomous Systems
+
 @item CIRC
 Cross Interleaved Reed-solomon Code (CD)
 
@@ -1194,6 +1251,9 @@ Comite International Special des Perturbations Radioelectriques (org.)
 @item CISS
 Center for Information Systems Security (org., JIEO, DISA, mil., USA)
 
+@item CISS
+Confirmation Interactive Site Server [technology]
+
 @item CISSP
 Certified Information Systems Security Professional (ISC2)
 
@@ -1221,6 +1281,9 @@ Commercial Internet eXchange (ISP)
 @item CJK
 Chinese - Japanese - Korean [encoding]
 
+@item CKOA
+Cygwin Keeper of Acronyms (Cygwin, OLOCA)
+
 @item CL
 Column Address Strobe Latency (CAS, IC)
 
@@ -1260,6 +1323,9 @@ Class LIbrary (CLI)
 @item CLI
 CLear Interrupt (assembler)
 
+@item CLI
+Clearly Less Intimidating (slang, Cygwin)
+
 @item CLI
 Command Line Interpreter / Interface (OS)
 
@@ -1368,6 +1434,9 @@ Cambridge Model Distributed System (OS)
 @item CME
 Component Management Entity
 
+@item CME
+Core Managed Environment (Phoenix, MBR), "cME"
+
 @item CMGA
 Community of Massive Gaming Agents Internet, Germany, DTAG
 
@@ -1420,7 +1489,7 @@ CMIP Over TCP (OSI, RFC 1189, CMIP, TCP)
 Chip MultiProcessing (IBM, HP, Sun)
 
 @item CMP
-Container-Managed Persistence [beans] (Java, EJB)
+Container-Managed Persistence (Java, EJB, BMP)
 
 @item CMP
 Cooperative Marketing Partner (DEC)
@@ -1566,6 +1635,9 @@ Check Out (RCS)
 @item CO
 Connection Oriented (CL)
 
+@item COA
+Certificate of Authenticity (MS, Windows, XP)
+
 @item COAS
 Caldera Open Administration System (Linux)
 
@@ -1803,6 +1875,9 @@ Cost Per Copy
 @item CPCI
 Compact Peripheral Component Interconnect (PCI), "cPCI"
 
+@item CPCM
+Content Protection Copyright Management (DVB, CPTWG)
+
 @item CPCS
 Common Part Convergence Sublayer (ATM)
 
@@ -1917,6 +1992,9 @@ Configurable PostScript Interpreter
 @item CPSR
 Computer Professionals for Social Responsibility (org., USA)
 
+@item CPTWG
+Copyright Protection Technical Working Group (DVB, WG)
+
 @item CPU
 Central Processing Unit
 
@@ -2127,6 +2205,9 @@ C SHell (Unix, BSD, Shell)
 @item CSH
 Complementary Software House (DEC)
 
+@item CSI
+Common System Interface (Intel, Xeon)
+
 @item CSI
 CompuServe Incorporated (ISP)
 
@@ -2301,6 +2382,9 @@ Canadian Trusted Computer Product Evaluation Criteria (Canada)
 @item CTD
 Cell Transfer Delay (UNI, ATM, QOS)
 
+@item CTDW
+Cygwin Technical Documentation Writer (Cygwin)
+
 @item CTE
 Compliance Test and Evaluation, "CT & E"
 
@@ -2325,6 +2409,9 @@ Communication Trunk of Medium range Mil., Germany
 @item CTOS
 Cassette Tape Operating System (OS, Datapoint)
 
+@item CTP
+Community Technology Preview
+
 @item CTP
 Cordless Telephony Profile (Bluetooth)
 
@@ -2442,6 +2529,9 @@ Continuous Variable Delta Modulation (telecommunication)
 @item CVSELP
 Codex Vector Sum Excited Linear Prediction [algorithm] (Motorola, VOFR)
 
+@item CVSS
+Common Vulnerability Scoring System (NIAC)
+
 @item CVW
 MITRE Collaborative Virtual Workspace license
 
@@ -2469,6 +2559,9 @@ Common X-windows Interface (Unix)
 @item CXML
 Commerce eXtensible Markup Language (XML), "cXML"
 
+@item CXTP
+ConteXt Transfer Protocol (RFC 4067)
+
 @item CYMK
 Cyan, Yellow, Magenta, blacK (color system)
 
