@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2005 Oliver Heidelbach
+@c Copyright (C) 1993/2006 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -27,6 +27,9 @@ High Availability Clustered Multi Processing (IBM, RS/6000, Bull), "HA/CMP"
 @item HADR
 High Availability Disaster Recovery (Informix, DB2, DB)
 
+@item HAL
+Hackers At Large (org.)
+
 @item HAL
 Hard Array Logic
 
@@ -67,7 +70,7 @@ Home Audio Video Interoperability (org., Grundig, Hitachi, Matsushita, Philips,
 Host Bus Adapter (SCSI)
 
 @item HBCI
-HomeBanking Computer Interface Internet, banking, Germany, HBCI, veraltet
+HomeBanking Computer Interface [old term] Internet, banking, Germany, HBCI
 
 @item HBT
 Hetero Bipolar Transistor (IBM, IC)
@@ -333,12 +336,18 @@ High Performance Peripheral Interface
 @item HIRD
 HURD of Interfaces Representing Depth (GNU, HURD)
 
+@item HIS
+HerstellerInitiative Software Org., Germany
+
 @item HISAM
 Hierarchical Indexed Sequential Access Method (SAM)
 
 @item HISP
 HIgh SPeed channel connector (Cray, I/O)
 
+@item HKS
+Horowitz Key Server (PGP, GPG, PKS, SKS)
+
 @item HLL
 High Level Language
 
@@ -363,6 +372,9 @@ Hue, Luminance, Saturation (color system, DTP)
 @item HLSL
 High Level Shader Language (DirectX)
 
+@item HM
+HyperMemory (graphics)
+
 @item HMA
 High Memory Area
 
@@ -468,6 +480,9 @@ Hewlett Packard Graphics Language (CAD, CAM, HP)
 @item HPIB
 Hewlett Packard Interface Bus (GPIB)
 
+@item HPLIP
+Hewlett Packard Linux Imaging and Printing (HP, Linux)
+
 @item HPM
 Hyper Page Mode
 
