@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2005 Oliver Heidelbach
+@c Copyright (C) 1993/2006 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -330,6 +330,9 @@ Message Conversion System
 @item MCS
 Modulation and Coding Scheme (EGPRS, mobile-systems)
 
+@item MCS
+Multi-Category Security (SELinux)
+
 @item MCS
 MultiCast Server
 
@@ -423,6 +426,9 @@ Meta Data Coalition
 @item MDCT
 Modified Discrete Cosine Transformation
 
+@item MDD
+Model Driven Design (MDS)
+
 @item MDDB
 MultiDimensional DataBase (DB)
 
@@ -456,6 +462,9 @@ MODEM Developers Kit (MODEM, MS)
 @item MDL
 Microstation Development Language (CAD)
 
+@item MDM
+Master Data Management
+
 @item MDM
 MicroDiskModule
 
@@ -471,6 +480,9 @@ Manufacturing Design Rule Checker
 @item MDS
 Manufacturing Design System
 
+@item MDSD
+Model Driven Software Development
+
 @item MDSE
 Message Delivery Service Element
 
@@ -570,6 +582,9 @@ Macro Expansion Template Attribute Language (TAL, ZPT, ZOPE)
 @item METDST
 Middle European Time Daylight Saving Time [+0200] (TZ, MET, MEZ)
 
+@item MEU
+Multiformat  Engine Unit (LCD, Sony)
+
 @item MEZ
 MittelEuropaeische [sommer] Zeit [+0200] (TZ)
 
@@ -585,6 +600,9 @@ Microsoft Foundation Classes (MS)
 @item MFC
 Music Feature Card (IBM, Yamaha, MIDI)
 
+@item MFD
+Multi-Functional Display (Airbus, A380)
+
 @item MFENET
 Magnetic Fusion Energy NETwork
 
@@ -699,6 +717,9 @@ Media Interface Connector (FDDI, PMD)
 @item MIC
 Memory in Cassette (Seagate, EEPROM, Streamer, AIT)
 
+@item MIC
+Memory Interface Controller (IBM, Cell)
+
 @item MIC
 Message Integrity Check / Code
 
@@ -744,6 +765,9 @@ Mach Interface Generator (Mach)
 @item MII
 Media Independent Interface
 
+@item MIKEY
+Multimedia Internet KEYing (cryptography, VoIP)
+
 @item MIL
 Matrox Imaging Library
 
@@ -768,6 +792,9 @@ Multipurpose Internet Mail Extensions (RFC 2045/2046/2047/2048/2049, IETF)
 @item MIMO
 Multiple Input, Multiple Output (Agere-Systems, WLAN, Bell)
 
+@item MIMO
+Multiple Input, Multiple Output (WLAN)
+
 @item MIMOLA
 Machine Independent MicrOprogramming LAnguage (HDL)
 
@@ -825,6 +852,12 @@ Mega Iterations per Second
 @item MISD
 Multiple Instruction [stream], Single Data [stream] (CPU)
 
+@item MISO
+Multiple Input, Single Output (WLAN)
+
+@item MISRA
+Motor Industry Software Reliability Association (UK)
+
 @item MISS
 Mecklenburg Internet Service System (ISP)
 
@@ -910,7 +943,7 @@ MultiLink Point-to-Point Protocol (PPP)
 Multi-channel Linear Recording [technology] (Tandberg, Streamer)
 
 @item MLS
-MultiLevel Secure [operating systems / platforms]
+MultiLevel Secure [operating systems / platforms] (SELinux)
 
 @item MLT
 Master Lower Tester (ISO 9646-3, TTCN)
@@ -948,6 +981,9 @@ MultiMedia Commands (SAM)
 @item MMC
 MultiMediaCard
 
+@item MMCA
+MultiMediaCard Association (org.)
+
 @item MMCD
 MultiMedia Compact Disk (Sony, Philips, CD)
 
@@ -1005,6 +1041,9 @@ MultiMedia Presentation Manager /2 (IBM, OS/2), "MMPM/2"
 @item MMR
 Modified Modified Read (Fax)
 
+@item MMRSG
+Mobile Multi-hop Relay Study Group (IEEE), "MMR SG"
+
 @item MMS
 Manufacturing Message Specifications / Standard (MAP, EIA, RS-511, ISO, DIS 9506)
 
@@ -1455,6 +1494,9 @@ Media Recognition System (DAT)
 @item MRSE
 Message Retrieval Service Element
 
+@item MRTD
+Machine Readable Travel Document(s)
+
 @item MRTG
 Multi Router Traffic Grapher
 
@@ -1521,6 +1563,9 @@ Mass Storage Control Protocol
 @item MSCS
 MicroSoft Cluster Server [Wolfpack] (MS, Cluster)
 
+@item MSCT
+Microsoft Shared Computer Toolkit (MS)
+
 @item MSD
 Most Significant Digit
 
@@ -1566,6 +1611,9 @@ MicroSoft Fax Information Service (MS)
 @item MSFP
 Management Service Focal Point (IBM)
 
+@item MSFTEU
+Maximum Surprise For The End User (slang, Cygwin)
+
 @item MSH
 Microsoft SHell (MS)
 
@@ -1665,6 +1713,9 @@ MicroSoft Remote Procedure Call (MS, DCOM), "MS-RPC"
 @item MSS
 Maximum Segment Size (TCP, ADSL)
 
+@item MSS
+Microsoft Speech Server (MS)
+
 @item MSS
 MIMOLA Software System (MIMOLA)
 
@@ -1831,7 +1882,7 @@ MULtiplexer-DEMultiplexer
 MULtilingual Enhancement of GNU EMACS (EMACS, GNU)
 
 @item MULTICS
-MULTiplexed Information and Computing Service (OS)
+MULTiplexed Information and Computing Service (OS, MIT, Bell)
 
 @item MULTOS
 MULtimedia Office Server (OA, BIS, ESPRIT)
