@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2005 Oliver Heidelbach
+@c Copyright (C) 1993/2006 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -366,6 +366,12 @@ Remote Desktop Protocol (MS)
 @item RDP
 Remote Display Protocol (MS, Windows NT, ASP)
 
+@item RDQL
+Resource Description Query Language (RDF, HP, Java)
+
+@item RDR
+Remote Data Recovery (Ontrack)
+
 @item RDR
 Request Data with Reply (Feldbus)
 
@@ -393,6 +399,9 @@ Radio Digital Terminal
 @item RDT
 Restricted Data Transmissions
 
+@item RDTP
+[secure] Raw Data Transfer Protocol
+
 @item RE
 RAID Edition (WD, RAID)
 
@@ -558,6 +567,9 @@ Red Hat Certified Engineer (RedHat, Linux)
 @item RHCT
 Red Hat Certified Technician (RedHat, Linux)
 
+@item RHCX
+Red Hat Certified eXaminer
+
 @item RHEL
 Red Hat Enterprise Linux (Linux, RedHat)
 
@@ -588,6 +600,9 @@ Research Issues in Data Engineering (IEEE-CS)
 @item RIE
 Reactive Ion Etching (IC)
 
+@item RIF
+Requirements Interchange Format (HIS)
+
 @item RIF
 Routing Information Field (Token Ring)
 
@@ -789,6 +804,9 @@ Realtime Multitasking Operating System (SNI, OS)
 @item RMS
 Reason Maintenance System (AI)
 
+@item RMS
+Reliant Monitor Services (FSC)
+
 @item RMS
 Remote Monitoring System [bus]
 
@@ -870,6 +888,9 @@ Remote Object Class Factory
 @item ROD
 Rewritable Optical Disk (OD)
 
+@item RODC
+Read-Only DOMAIN Controller (MS, AD)
+
 @item ROFL
 Roar Out From Laughing (slang, Usenet, IRC)
 
@@ -945,6 +966,9 @@ Remote Procedure Call Language (ONC, Sun)
 @item RPCS
 Ricoh Printer ???
 
+@item RPDFP
+Remote Physical Device Finger Printing (NAT, IP)
+
 @item RPE
 Remote Peripheral Equipment
 
@@ -1053,6 +1077,9 @@ Remote Service Access Point (SAP)
 @item RSAT
 Reliability and System Architecture Testing
 
+@item RSB
+Remote view Service Board (FSC)
+
 @item RSBAC
 Rule Set Base Access Control (Linux)
 
@@ -1065,6 +1092,9 @@ Remote Source Control System
 @item RSCS
 Remote Spooling Communications Subsystem (IBM, VM, NJE)
 
+@item RSCT
+Reliable Scalable Cluster Technology (IBM)
+
 @item RSDP
 Root System Description Pointer (ACPI)
 
@@ -1110,6 +1140,9 @@ Remote Subscriber Line Module
 @item RSM
 Remote Switching Module
 
+@item RSMMC
+Reduced Size MultiMediaCard (MMC), "RS-MMC"
+
 @item RSN
 Real Soon Now (slang)
 
@@ -1170,6 +1203,9 @@ Routing Type
 @item RTA
 Rapid Thermal Annealling (IC, MOSFET)
 
+@item RTA
+Real Time Adherence
+
 @item RTA
 Real-Time Accelerator
 
@@ -1341,6 +1377,9 @@ Radio Tele TYpe
 @item RTU
 Real Time Unix (Unix)
 
+@item RTU
+Remote Terminal Unit (ESA, Venus-Express)
+
 @item RTUX
 Real Time UniX (OS, Emerge Systems)
 
